@@ -8,28 +8,27 @@ To run this:
    interactive console
 """
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import pygtk
-    pygtk.require('2.0')
+
+    pygtk.require("2.0")
     import gtk
-    
-    
+
     def hello_world(wigdet, data=None):
         print("Hello World")
-    
+
     def delete_event(widget, event, data=None):
         return False
-    
+
     def destroy(widget, data=None):
         gtk.main_quit()
-    
+
     window = gtk.Window(gtk.WINDOW_TOPLEVEL)
     window.connect("delete_event", delete_event)
     window.connect("destroy", destroy)
     button = gtk.Button("Hello World")
     button.connect("clicked", hello_world, None)
-    
+
     window.add(button)
     button.show()
     window.show()
-    
