@@ -8,26 +8,24 @@ To run this:
    interactive console
 """
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     from gi.repository import Gtk
-    
-    
+
     def hello_world(wigdet, data=None):
         print("Hello World")
-    
+
     def delete_event(widget, event, data=None):
         return False
-    
+
     def destroy(widget, data=None):
         Gtk.main_quit()
-    
+
     window = Gtk.Window(Gtk.WindowType.TOPLEVEL)
     window.connect("delete_event", delete_event)
     window.connect("destroy", destroy)
     button = Gtk.Button("Hello World")
     button.connect("clicked", hello_world, None)
-    
+
     window.add(button)
     button.show()
     window.show()
-    
