@@ -631,8 +631,8 @@ class DebuggerRunner(object):
             msg = "TimeoutError"
             try:
                 writer.write_dump_threads()
-            except:
-                msg += " (note: error trying to dump threads on timeout)."
+            except Exception as e:
+                msg += " (note: error trying to dump threads on timeout: " + str(e) + ")."
             time.sleep(0.2)
             self.fail_with_message(msg, stdout, stderr, writer)
         except Exception as e:
@@ -647,8 +647,9 @@ class DebuggerRunner(object):
             except:
                 traceback.print_exc()
             finish[0] = True
+            print("Log on success: " + self.get_log_contents())
 
-    def fail_with_message(self, msg, stdout, stderr, writerThread):
+    def get_log_contents(self):
         log_contents = ""
         if self.pydevd_debug_file:
             for f in pydev_log.list_log_files(self.pydevd_debug_file):
@@ -656,6 +657,10 @@ class DebuggerRunner(object):
                     with open(f, "r") as stream:
                         log_contents += "\n-------------------- %s ------------------\n\n" % (f,)
                         log_contents += stream.read()
+        return log_contents
+
+    def fail_with_message(self, msg, stdout, stderr, writerThread):
+        log_contents = self.get_log_contents()
         msg += (
             "\n\n===========================\nStdout: \n"
             + "".join(stdout)
@@ -728,9 +733,12 @@ class AbstractWriterThread(threading.Thread):
                 "warning: Debugger speedups",
                 "pydev debugger: New process is launching",
                 "pydev debugger: To debug that process",
+                "pydevd: New process is launching",
+                "pydevd: To debug that process",
                 "*** Multiprocess",
                 "WARNING: This is a development server. Do not use it in a production deployment",
                 "Press CTRL+C to quit",
+                "pydevd: waiting for connection at:",
             )
         ):
             return True
@@ -1648,7 +1656,9 @@ class AbstractWriterThread(threading.Thread):
 
     def wait_for_thread_join(self, main_thread_id):
         def condition():
-            return self.get_frame_names(main_thread_id) in (
+            names = self.get_frame_names(main_thread_id)
+            return names in (
+                ["join", "<module>"],
                 ["wait", "join", "<module>"],
                 ["_wait_for_tstate_lock", "join", "<module>"],
                 ["_wait_for_tstate_lock", "join", "<module>", "_run_code", "_run_module_code", "run_path"],
