@@ -1,7 +1,7 @@
 import unittest
 
+
 class StillYetAnotherSampleTest(unittest.TestCase):
-    
     def setUp(self):
         return
 
@@ -12,5 +12,5 @@ class StillYetAnotherSampleTest(unittest.TestCase):
         pass
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
